@@ -23,14 +23,12 @@ class Lexer(object):
         """
         Tokenizes `self.src` and yields `Token` objects..
         """
-        empty_file = True
         for line in self.src:
             self.lineno += 1
             # Ignore blank lines and comments.
             stripped_line = line.strip()
             if not stripped_line or (stripped_line and stripped_line[0] == '/'):
                 continue
-            empty_file = False
             # Check for indent changes.
             indent_change = self.check_indent(line)
             if indent_change:
@@ -51,37 +49,37 @@ class Lexer(object):
             handler = self.handlers.get(first_char, self.handle_html)
             ret = handler(stripped_line)
             if ret: yield ret
-        if not empty_file:
-            # yield implicity closed tags.
-            indents = self.indents
-            lineno = self.lineno
-            while indents:
-                yield IndentToken(UNINDENT, lineno, ' ' * indents.pop())
-                lineno += 1
-            # unindent for `html` for which no indent was recorded.
-            yield IndentToken(UNINDENT, lineno, '')
+        # yield implicity closed tags.
+        indents = self.indents
+        lineno = self.lineno
+        while indents:
+            yield IndentToken(UNINDENT, lineno, ' ' * indents.pop())
+            lineno += 1
+        # unindent for `html` for which no indent was recorded.
+        yield IndentToken(UNINDENT, lineno, '')
 
     def check_indent(self, line):
         """
         Checks for increase or decrease in indent.
         yields `IndentToken` if index changes.
         """
-        indent = self.whitespace.match(line)
-        if indent:
-            indent = indent.group()
-            indent_len = len(indent)
-            indents = self.indents
-            # Record indents.
-            if not indents or indent_len > indents[-1]:
-                # Indents are part of text if in text block.
-                if not self.in_text_block:
-                    indents.append(indent_len)
-                    return INDENT, [IndentToken(INDENT, self.lineno, indent)]
-            elif indent_len < indents[-1]:
-                changes = []
-                while indents and indents[-1] > indent_len:
-                    changes.append(IndentToken(UNINDENT, self.lineno, ' ' * indents.pop()))
-                return UNINDENT, changes
+        current_indent = self.whitespace.match(line)
+        indent_len = 0
+        if current_indent:
+            current_indent = current_indent.group()
+            indent_len = len(current_indent)
+        indents = self.indents
+        # Record indents.
+        if (not indents and current_indent) or (indents and indent_len > indents[-1]):
+            # Indents are part of text if in text block.
+            if not self.in_text_block:
+                indents.append(indent_len)
+                return INDENT, [IndentToken(INDENT, self.lineno, current_indent)]
+        elif indents and indent_len < indents[-1]:
+            changes = []
+            while indents and indents[-1] > indent_len:
+                changes.append(IndentToken(UNINDENT, self.lineno, ' ' * indents.pop()))
+            return UNINDENT, changes
         return False
 
     def extract_values(self, tag_name, line):
